permission.tests package
========================

Subpackages
-----------

.. toctree::

    permission.tests.test_decorators
    permission.tests.test_logics
    permission.tests.test_templatetags
    permission.tests.test_utils

Submodules
----------

permission.tests.compatibility module
-------------------------------------

.. automodule:: permission.tests.compatibility
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.models module
------------------------------

.. automodule:: permission.tests.models
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_backends module
-------------------------------------

.. automodule:: permission.tests.test_backends
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_handlers module
-------------------------------------

.. automodule:: permission.tests.test_handlers
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.utils module
-----------------------------

.. automodule:: permission.tests.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission.tests
    :members:
    :undoc-members:
    :show-inheritance:
